EXPORTS
	?CancelMessageSend@CNcmConnectionMultiplexer@@UAEXIIPBVMNcmSenderObserver@@@Z @ 1 NONAME ; void CNcmConnectionMultiplexer::CancelMessageSend(unsigned int, unsigned int, class MNcmSenderObserver const *)
	?CloseTcpConnection@CNcmConnectionMultiplexer@@UAEXII@Z @ 2 NONAME ; void CNcmConnectionMultiplexer::CloseTcpConnection(unsigned int, unsigned int)
	?CreateConnectionL@CNcmConnectionMultiplexer@@UAEIIABVTInetAddr@@@Z @ 3 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateConnectionL(unsigned int, class TInetAddr const &)
	?CreateConnectionL@CNcmConnectionMultiplexer@@UAEIII@Z @ 4 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateConnectionL(unsigned int, unsigned int)
	?CreateSessionL@CNcmConnectionMultiplexer@@QAEIKII@Z @ 5 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateSessionL(unsigned long, unsigned int, unsigned int)
	?CreateStreamL@CNcmConnectionMultiplexer@@QAEIIHI@Z @ 6 NONAME ; unsigned int CNcmConnectionMultiplexer::CreateStreamL(unsigned int, int, unsigned int)
	?FreePort@CNcmPortStore@@QAEXI@Z @ 7 NONAME ; void CNcmPortStore::FreePort(unsigned int)
	?GetSessionInfoL@CNcmConnectionMultiplexer@@QAEPAVRSocketServ@@IAAV?$TBuf@$0IA@@@@Z @ 8 NONAME ; class RSocketServ * CNcmConnectionMultiplexer::GetSessionInfoL(unsigned int, class TBuf<128> &)
	?GetStreamInfoL@CNcmConnectionMultiplexer@@UAEXIAAKAAHAAI@Z @ 9 NONAME ; void CNcmConnectionMultiplexer::GetStreamInfoL(unsigned int, unsigned long &, int &, unsigned int &)
	?LocalIPAddressL@CNcmConnectionMultiplexer@@UAEAAVTInetAddr@@II@Z @ 10 NONAME ; class TInetAddr & CNcmConnectionMultiplexer::LocalIPAddressL(unsigned int, unsigned int)
	?NewL@CNcmConnectionMultiplexer@@SAPAV1@AAVMNcmConnectionMultiplexerObserver@@@Z @ 11 NONAME ; class CNcmConnectionMultiplexer * CNcmConnectionMultiplexer::NewL(class MNcmConnectionMultiplexerObserver &)
	?OpenTcpConnectionL@CNcmConnectionMultiplexer@@UAEXIIW4TNATFWTcpConnectionSetup@@ABVTInetAddr@@@Z @ 12 NONAME ; void CNcmConnectionMultiplexer::OpenTcpConnectionL(unsigned int, unsigned int, enum TNATFWTcpConnectionSetup, class TInetAddr const &)
	?Port@CNcmPortStore@@QAEIXZ @ 13 NONAME ; unsigned int CNcmPortStore::Port(void)
	?PortStoreL@CNcmConnectionMultiplexer@@QAEAAVCNcmPortStore@@I@Z @ 14 NONAME ; class CNcmPortStore & CNcmConnectionMultiplexer::PortStoreL(unsigned int)
	?RegisterConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmConnectionObserver@@@Z @ 15 NONAME ; void CNcmConnectionMultiplexer::RegisterConnectionObserverL(unsigned int, class MNcmConnectionObserver &)
	?RegisterIncomingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmIncomingConnectionObserver@@@Z @ 16 NONAME ; void CNcmConnectionMultiplexer::RegisterIncomingConnectionObserverL(unsigned int, class MNcmIncomingConnectionObserver &)
	?RegisterMediaWrapperL@CNcmConnectionMultiplexer@@QAEXPAVMNATFWMediaWrapper@@@Z @ 17 NONAME ; void CNcmConnectionMultiplexer::RegisterMediaWrapperL(class MNATFWMediaWrapper *)
	?RegisterMessageObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmMessageObserver@@@Z @ 18 NONAME ; void CNcmConnectionMultiplexer::RegisterMessageObserverL(unsigned int, class MNcmMessageObserver &)
	?RegisterOutgoingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmOutgoingConnectionObserver@@@Z @ 19 NONAME ; void CNcmConnectionMultiplexer::RegisterOutgoingConnectionObserverL(unsigned int, class MNcmOutgoingConnectionObserver &)
	?RemoveConnectionL@CNcmConnectionMultiplexer@@UAEXII@Z @ 20 NONAME ; void CNcmConnectionMultiplexer::RemoveConnectionL(unsigned int, unsigned int)
	?RemoveSessionL@CNcmConnectionMultiplexer@@QAEXI@Z @ 21 NONAME ; void CNcmConnectionMultiplexer::RemoveSessionL(unsigned int)
	?RemoveStreamL@CNcmConnectionMultiplexer@@QAEXI@Z @ 22 NONAME ; void CNcmConnectionMultiplexer::RemoveStreamL(unsigned int)
	?ResolveDestinationAddressL@CNcmConnectionMultiplexer@@QAEXIABVTDesC8@@IAAVTInetAddr@@@Z @ 23 NONAME ; void CNcmConnectionMultiplexer::ResolveDestinationAddressL(unsigned int, class TDesC8 const &, unsigned int, class TInetAddr &)
	?SendL@CNcmConnectionMultiplexer@@UAEXIABVTDesC8@@ABVTInetAddr@@1@Z @ 24 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, class TDesC8 const &, class TInetAddr const &, class TInetAddr const &)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@ABVTInetAddr@@PAVMNcmSenderObserver@@@Z @ 25 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, class TInetAddr const &, class MNcmSenderObserver *)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@HPAVMNcmSenderObserver@@@Z @ 26 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, int, class MNcmSenderObserver *)
	?SendL@CNcmConnectionMultiplexer@@UAEXIIABVTDesC8@@PAVMNcmSenderObserver@@@Z @ 27 NONAME ; void CNcmConnectionMultiplexer::SendL(unsigned int, unsigned int, class TDesC8 const &, class MNcmSenderObserver *)
	?SetAcceptedFromAddressL@CNcmConnectionMultiplexer@@UAEXIIABVTInetAddr@@@Z @ 28 NONAME ; void CNcmConnectionMultiplexer::SetAcceptedFromAddressL(unsigned int, unsigned int, class TInetAddr const &)
	?SetReceivingStateForMediaL@CNcmConnectionMultiplexer@@QAEXIIW4TNATFWStreamingState@@@Z @ 29 NONAME ; void CNcmConnectionMultiplexer::SetReceivingStateForMediaL(unsigned int, unsigned int, enum TNATFWStreamingState)
	?SetReceivingStateL@CNcmConnectionMultiplexer@@UAEXIIW4TNATFWStreamingState@@@Z @ 30 NONAME ; void CNcmConnectionMultiplexer::SetReceivingStateL(unsigned int, unsigned int, enum TNATFWStreamingState)
	?SetSendingStateForMediaL@CNcmConnectionMultiplexer@@QAEXIIW4TNATFWStreamingState@@@Z @ 31 NONAME ; void CNcmConnectionMultiplexer::SetSendingStateForMediaL(unsigned int, unsigned int, enum TNATFWStreamingState)
	?SetSendingStateL@CNcmConnectionMultiplexer@@UAEXIIABVTInetAddr@@W4TNATFWStreamingState@@@Z @ 32 NONAME ; void CNcmConnectionMultiplexer::SetSendingStateL(unsigned int, unsigned int, class TInetAddr const &, enum TNATFWStreamingState)
	?UnregisterConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmConnectionObserver@@@Z @ 33 NONAME ; void CNcmConnectionMultiplexer::UnregisterConnectionObserverL(unsigned int, class MNcmConnectionObserver &)
	?UnregisterIncomingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmIncomingConnectionObserver@@@Z @ 34 NONAME ; void CNcmConnectionMultiplexer::UnregisterIncomingConnectionObserverL(unsigned int, class MNcmIncomingConnectionObserver &)
	?UnregisterMessageObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmMessageObserver@@@Z @ 35 NONAME ; void CNcmConnectionMultiplexer::UnregisterMessageObserverL(unsigned int, class MNcmMessageObserver &)
	?UnregisterOutgoingConnectionObserverL@CNcmConnectionMultiplexer@@UAEXIAAVMNcmOutgoingConnectionObserver@@@Z @ 36 NONAME ; void CNcmConnectionMultiplexer::UnregisterOutgoingConnectionObserverL(unsigned int, class MNcmOutgoingConnectionObserver &)

